@@ -1,19 +1,22 @@
+use 5.008;    #utf8
 use strict;
 use warnings;
+use utf8;
 
 package Git::PurePerl::Walker::Role::Method;
-BEGIN {
-  $Git::PurePerl::Walker::Role::Method::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Git::PurePerl::Walker::Role::Method::VERSION = '0.002000';
-}
 
-# FILENAME: Method.pm
-# CREATED: 28/05/12 16:33:59 by Kent Fredric (kentnl) <kentfredric@gmail.com>
+our $VERSION = '0.003000';
+
 # ABSTRACT: A method for traversing a git repository
 
-use Moose::Role;
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Moose::Role qw( with requires );
+
+
+
+
+
 
 
 with 'Git::PurePerl::Walker::Role::HasRepo';
@@ -22,27 +25,81 @@ with 'Git::PurePerl::Walker::Role::HasRepo';
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 requires 'current';
 
 
+
+
+
+
+
+
+
+
+
 requires 'has_next';
 
 
+
+
+
+
+
+
+
 requires 'next';
 
 
+
+
+
+
+
+
+
 requires 'peek_next';
 
 
+
+
+
+
+
+
+
+
 requires 'reset';
 
 no Moose::Role;
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -50,7 +107,7 @@ Git::PurePerl::Walker::Role::Method - A method for traversing a git repository
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 REQUIRES METHODS
 
@@ -113,10 +170,9 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
