@@ -1,19 +1,22 @@
+use 5.008;    # utf8
 use strict;
 use warnings;
+use utf8;
 
 package Git::PurePerl::Walker::Role::OnCommit;
-BEGIN {
-  $Git::PurePerl::Walker::Role::OnCommit::AUTHORITY = 'cpan:KENTNL';
-}
-{
-  $Git::PurePerl::Walker::Role::OnCommit::VERSION = '0.002000';
-}
 
-# FILENAME: OnCommit.pm
-# CREATED: 28/05/12 16:35:27 by Kent Fredric (kentnl) <kentfredric@gmail.com>
+our $VERSION = '0.003000';
+
 # ABSTRACT: An event to execute when a commit is encountered
 
-use Moose::Role;
+our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
+
+use Moose::Role qw( with requires );
+
+
+
+
+
 
 
 with 'Git::PurePerl::Walker::Role::HasRepo';
@@ -22,17 +25,53 @@ with 'Git::PurePerl::Walker::Role::HasRepo';
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 requires 'handle';
 
 
+
+
+
+
+
+
+
 requires 'reset';
 no Moose::Role;
 1;
 
 __END__
+
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -40,7 +79,7 @@ Git::PurePerl::Walker::Role::OnCommit - An event to execute when a commit is enc
 
 =head1 VERSION
 
-version 0.002000
+version 0.003000
 
 =head1 REQUIRES METHODS
 
@@ -56,7 +95,7 @@ do something with.
 
 =head2 reset
 
-This method is signaled when the associated repository is resetting its iteration. 
+This method is signaled when the associated repository is resetting its iteration.
 
 You can either no-op this, or make it do something useful.
 
@@ -86,10 +125,9 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
